/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { Status, User } from './Common';
import { Icon } from './Icon';
export interface ObjectsResponse {
    objectEntries: ObjectEntity[];
    objectTypeAttributes?: ObjectTypeAttribute[];
    objectTypeId?: number;
    objectTypeIsInherited?: boolean;
    abstractObjectType?: boolean;
    totalFilterCount: number;
    startIndex: number;
    toIndex: number;
    pageObjectSize: number;
    pageNumber: number;
    orderByTypeAttrId?: number;
    orderWay?: string;
    iql?: string;
    qlQuery: string;
    iqlSearchResult?: boolean;
    qlQuerySearchResult?: boolean;
    conversionPossible?: boolean;
    matchedFilterValues?: Record<any, any>;
    inheritanceTree?: Record<any, any>;
    pageSize: number;
}
export interface ObjectEntity {
    id: number;
    label: string;
    objectKey: string;
    avatar: Avatar;
    objectType: ObjectType;
    created: string;
    updated: string;
    hasAvatar: boolean;
    timestamp: number;
    attributes?: Attribute[];
    _links?: {
        self: string;
    };
    name?: string;
}
export interface Avatar {
    id?: number;
    avatarUUID?: string;
    url16: string;
    url48: string;
    url72: string;
    url144: string;
    url288: string;
    objectId: number;
}
export interface ObjectType {
    id: number;
    name: string;
    description?: string;
    type: number;
    icon: Icon;
    position: number;
    created: string;
    updated: string;
    objectCount: number;
    objectSchemaId: number;
    inherited: boolean;
    abstractObjectType: boolean;
    parentObjectTypeInherited: boolean;
    parentObjectTypeId?: number;
}
export interface Attribute {
    id: number;
    objectTypeAttribute?: ObjectTypeAttribute;
    objectTypeAttributeId: number;
    objectAttributeValues: ObjectAttributeValue[];
    objectId?: number;
}
export interface ObjectAttributeValue {
    value?: string;
    searchValue?: string;
    referencedObject?: ObjectEntity;
    user?: User;
    group?: {
        avatarUrl: string;
        name: string;
    };
    confluencePage?: {
        id: string;
        title: string;
        url: string;
    };
    version?: {
        avatarUrl: string;
        name: string;
        id: number;
        url: string;
    };
    project?: {
        avatarUrl: string;
        id: number;
        name: string;
        key: string;
        url: string;
    };
    status?: Status;
    displayValue: string;
    referencedType?: boolean;
}
export interface ObjectTypeAttribute {
    id: number;
    objectType?: ObjectType;
    name?: string;
    label: boolean;
    type: number;
    defaultType: {
        id: number;
        name: string;
    };
    typeValue?: string;
    typeValueMulti?: string[];
    additionalValue?: string;
    referenceType?: ReferenceType;
    referenceObjectTypeId?: number;
    referenceObjectType?: ObjectType;
    confluenceTypeValue?: {
        id?: string;
        name?: string;
        url?: string;
        error?: boolean;
    };
    confluenceAddValue?: {
        key?: string;
        name?: string;
        error?: boolean;
    };
    versionTypeValues?: {
        avatarUrl: string;
        id: number;
        name: string;
        key: string;
        url: string;
    };
    editable?: boolean;
    system?: boolean;
    indexed: boolean;
    sortable?: boolean;
    summable?: boolean;
    minimumCardinality?: number;
    maximumCardinality?: number;
    suffix: string;
    removable?: boolean;
    objectAttributeExists?: boolean;
    hidden?: boolean;
    includeChildObjectTypes?: boolean;
    uniqueAttribute?: boolean;
    regexValidation?: boolean;
    iql?: string;
    qlQuery?: string;
    option?: string;
    position?: number;
    description?: string;
}
export interface HistoryResponse {
    actor: User;
    id: number;
    affectedAttribute?: string;
    oldValue?: string;
    newValue?: string;
    type: number;
    created: string;
    objectId: number;
}
export interface ObjectReferenceTypeInfo {
    referenceTypes?: ReferenceType[];
    objectType: ObjectType;
    numberOfReferencedObjects: number;
    openIssuesExists: boolean;
}
export interface ReferenceType {
    id?: number;
    name: string;
    description?: string;
    color?: string;
    url16?: string;
    removable?: boolean;
    objectSchemaId?: number;
}
export interface TicketsResponse {
    tickets?: Ticket[];
    allTicketsQuery: string;
}
export interface Ticket {
    key: string;
    id: number;
    reporter: string;
    created: string;
    updated: string;
    title: string;
    status: {
        name: string;
        colorName: string;
    };
    type: {
        name: string;
        description: string;
        iconUrl: string;
    };
    priority: {
        name: string;
        iconUrl: string;
    };
}
export interface ObjectSchemasResponse {
    objectschemas: ObjectSchema;
}
export interface ObjectSchema {
    id: number;
    name: string;
    objectSchemaKey: string;
    description?: string;
    status?: 'Ok';
    created: string;
    updated: string;
    objectCount: number;
    objectTypeCount: number;
}
//# sourceMappingURL=Object.d.ts.map