/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { Headers, Response, BaseApiCore, ErrorStrategyOptionType, PlatformImplementation } from '@managed-api/commons-core';
import { CustomError } from './common';
import { CommonError, ErrorStrategyHandlers, ErrorStrategyOption } from './errorStrategy';
import { ErrorStrategyBuilder } from './builders/errorStrategy';
import { CreateAttachmentsRequest, CreateAttachmentsResponseOK, DeleteAttachmentRequest, DeleteAttachmentResponseOK, GetAttachmentsRequest, GetAttachmentsResponseOK } from './types/attachment';
import { CreateCommentRequest, CreateCommentResponseOK, GetCommentsRequest, GetCommentsResponseOK } from './types/comment';
import { GetGlobalIconsRequest, GetGlobalIconsResponseOK, GetIconRequest, GetIconResponseOK, GetIconsBySchemaRequest, GetIconsBySchemaResponseOK } from './types/icon';
import { StartImportRequest, StartImportResponseOK } from './types/import';
import { StartCurrentModeReindexRequest, StartCurrentModeReindexResponseOK, StartReindexRequest, StartReindexResponseOK } from './types';
import { GetObjectsRequest, GetObjectsResponseOK } from './types/aql';
import { GetImportProgressRequest, GetImportProgressResponseOK, GetReindexProgressRequest, GetReindexProgressResponseOK } from './types/progress';
import { GetQrCodeRequest, GetQrCodeResponseOK } from './types/qrcode';
import { CreateConfigStatusRequest, CreateConfigStatusResponseOK, DeleteConfigStatusRequest, DeleteConfigStatusResponseOK, GetConfigStatusesRequest, GetConfigStatusesResponseOK, GetConfigStatusRequest, GetConfigStatusResponseOK, UpdateConfigStatusRequest, UpdateConfigStatusResponseOK } from './types/config';
import { CreateObjectRequest, CreateObjectResponseOK, DeleteObjectRequest, DeleteObjectResponseOK, GetObjectRequest, GetObjectResponseOK, GetObjectsWithAqlRequest, GetObjectsWithAqlResponseOK, UpdateObjectRequest, UpdateObjectResponseOK } from './types/object';
import { CreateObjectAttributeRequest, CreateObjectAttributeResponseOK, GetObjectAttributeRequest, GetObjectAttributeResponseOK, GetObjectAttributesRequest, GetObjectAttributesResponseOK, UpdateObjectAttributeRequest, UpdateObjectAttributeResponseOK } from './types/object/attribute';
import { GetObjectHistoryRequest, GetObjectHistoryResponseOK } from './types/object/history';
import { GetObjectReferencesRequest, GetObjectReferencesResponseOK } from './types/object/reference';
import { GetObjectConnectedTicketsRequest, GetObjectConnectedTicketsResponseOK } from './types/object/ticket';
import { CreateObjectSchemaRequest, CreateObjectSchemaResponseOK, DeleteObjectSchemaRequest, DeleteObjectSchemaResponseOK, GetObjectSchemaObjectTypeAttributesRequest, GetObjectSchemaObjectTypeAttributesResponseOK, GetObjectSchemaObjectTypesRequest, GetObjectSchemaObjectTypesResponseOK, GetObjectSchemaRequest, GetObjectSchemaResponseOK, GetObjectSchemasRequest, GetObjectSchemasResponseOK, UpdateObjectSchemaRequest, UpdateObjectSchemaResponseOK } from './types/object/schema';
import { ChangeObjectTypePositionRequest, ChangeObjectTypePositionResponseOK, CreateObjectTypeRequest, CreateObjectTypeResponseOK, DeleteObjectTypeRequest, DeleteObjectTypeResponseOK, GetObjectTypeAttributesRequest, GetObjectTypeAttributesResponseOK, GetObjectTypeRequest, GetObjectTypeResponseOK, UpdateObjectTypeRequest, UpdateObjectTypeResponseOK } from './types/object/type';
import { CreateObjectTypeAttributeRequest, CreateObjectTypeAttributeResponseOK, DeleteObjectTypeAttributeRequest, DeleteObjectTypeAttributeResponseOK, UpdateObjectTypeAttributeRequest, UpdateObjectTypeAttributeResponseOK } from './types/object/type/attribute';
export interface JSMOnPremiseAssetsApiCoreOptions extends ErrorStrategyOption {
}
type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, CustomError, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class JSMOnPremiseAssetsApiCore extends BaseApiCore {
    private options?;
    Attachment: AttachmentGroup;
    Comment: CommentGroup;
    Icon: IconGroup;
    Import: ImportGroup;
    Index: IndexGroup;
    Aql: AqlGroup;
    Object: ObjectGroup;
    Progress: ProgressGroup;
    QRCode: QRCodeGroup;
    Config: ConfigGroup;
    All: AllGroup;
    constructor(options?: JSMOnPremiseAssetsApiCoreOptions);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, CustomError, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private Attachment;
    private Comment;
    private Icon;
    private Import;
    private Index;
    private Aql;
    private Object;
    private Progress;
    private QRCode;
    private Config;
    constructor(Attachment: AttachmentGroup, Comment: CommentGroup, Icon: IconGroup, Import: ImportGroup, Index: IndexGroup, Aql: AqlGroup, Object: ObjectGroup, Progress: ProgressGroup, QRCode: QRCodeGroup, Config: ConfigGroup);
    /**
     * Get object attachments
     * Alternative usage: Attachments.getAttachments
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments_object__objectid__get
     * @param options Request options.
     */
    getAttachments<T = GetAttachmentsResponseOK>(options: GetAttachmentsRequest): Promise<GetAttachmentsResponseOK | T>;
    /**
     * Create object attachments
     * Alternative usage: Attachments.createAttachments
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments_object__objectid__post
     * @param options Request options.
     */
    createAttachments<T = CreateAttachmentsResponseOK>(options: CreateAttachmentsRequest): Promise<CreateAttachmentsResponseOK | T>;
    /**
     * Delete object attachment
     * Alternative usage: Attachments.deleteAttachment
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments__attachmentid__delete
     * @param options Request options.
     */
    deleteAttachment<T = DeleteAttachmentResponseOK>(options: DeleteAttachmentRequest): Promise<DeleteAttachmentResponseOK | T>;
    /**
     * Create comments on objects
     * Alternative usage: Attachments.createComment
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#comment_create_post
     * @param options Request options.
     */
    createComment<T = CreateCommentResponseOK>(options: CreateCommentRequest): Promise<CreateCommentResponseOK | T>;
    /**
     * Get comments on objects
     * Alternative usage: Attachments.getComment
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#comment_object__objectid__get
     * @param options Request options.
     */
    getComments<T = GetCommentsResponseOK>(options: GetCommentsRequest): Promise<GetCommentsResponseOK | T>;
    /**
     * Load a single icon by id
     * Alternative usage: Icon.getIcon
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon__id__get
     * @param options Request options.
     */
    getIcon<T = GetIconResponseOK>(options: GetIconRequest): Promise<GetIconResponseOK | T>;
    /**
     * Get all existing global icons
     * Alternative usage: Icon.getGlobalIcons
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon_global_get
     * @param options Request options.
     */
    getGlobalIcons<T = GetGlobalIconsResponseOK>(options?: GetGlobalIconsRequest): Promise<GetGlobalIconsResponseOK | T>;
    /**
     * Fetch all configured icons from the object schema
     * Alternative usage: Icon.getIconsBySchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon_objectschema__objectschemaid__get
     * @param options Request options.
     */
    getIconsBySchema<T = GetIconsBySchemaResponseOK>(options: GetIconsBySchemaRequest): Promise<GetIconsBySchemaResponseOK | T>;
    /**
     * Start import
     * Alternative usage: Import.startImport
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#import_start__id__post
     * @param options Request options.
     */
    startImport<T = StartImportResponseOK>(options: StartImportRequest): Promise<StartImportResponseOK | T>;
    /**
     * Handle the indexing of Assets
     * Alternative usage: Import.startReindex
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#index_reindex_start_post
     * @param options Request options.
     */
    startReindex<T = StartReindexResponseOK>(options?: StartReindexRequest): Promise<StartReindexResponseOK | T>;
    /**
     * Only applicable in a Data Center environment. Resource to start a re-index of the current node. This reindex will not clean the entire cluster just refresh the objects in cache on the current data center node
     * Alternative usage: Import.startCurrentModeReindex
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#index_reindex_currentnode_post
     * @param options Request options.
     */
    startCurrentModeReindex<T = StartCurrentModeReindexResponseOK>(options?: StartCurrentModeReindexRequest): Promise<StartCurrentModeReindexResponseOK | T>;
    /**
     * Get objects
     * Alternative usage: Aql.getObjects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#aql_objects_get
     * @param options Request options.
     */
    getObjects<T = GetObjectsResponseOK>(options?: GetObjectsRequest): Promise<GetObjectsResponseOK | T>;
    /**
     * Get ongoing Assets processes
     * Alternative usage: Progress.getReindexProgress
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#progress_category_assets_reindex_reindex_get
     * @param options Request options.
     */
    getReindexProgress<T = GetReindexProgressResponseOK>(options?: GetReindexProgressRequest): Promise<GetReindexProgressResponseOK | T>;
    /**
     * Get progress for import source
     * Alternative usage: Progress.getImportProgress
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#progress_category_imports__id__get
     * @param options Request options.
     */
    getImportProgress<T = GetImportProgressResponseOK>(options: GetImportProgressRequest): Promise<GetImportProgressResponseOK | T>;
    /**
     * Get QR code for object
     * Alternative usage: QRCode.getQrCode
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#qrcode_object__objectid__code_png_get
     * @param options Request options.
     */
    getQrCode<T = GetQrCodeResponseOK>(options: GetQrCodeRequest): Promise<GetQrCodeResponseOK | T>;
    /**
     * Get the Assets statuses
     * Alternative usage: Config.getConfigStatuses
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype_get
     * @param options Request options.
     */
    getConfigStatuses<T = GetConfigStatusesResponseOK>(options: GetConfigStatusesRequest): Promise<GetConfigStatusesResponseOK | T>;
    /**
     * Create status
     * Alternative usage: Config.createConfigStatus
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype_post
     * @param options Request options.
     */
    createConfigStatus<T = CreateConfigStatusResponseOK>(options: CreateConfigStatusRequest): Promise<CreateConfigStatusResponseOK | T>;
    /**
     * Get status
     * Alternative usage: Config.getConfigStatus
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__get
     * @param options Request options.
     */
    getConfigStatus<T = GetConfigStatusResponseOK>(options: GetConfigStatusRequest): Promise<GetConfigStatusResponseOK | T>;
    /**
     * Update status
     * Alternative usage: Config.updateConfigStatus
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__put
     * @param options Request options.
     */
    updateConfigStatus<T = UpdateConfigStatusResponseOK>(options: UpdateConfigStatusRequest): Promise<UpdateConfigStatusResponseOK | T>;
    /**
     * Delete status
     * Alternative usage: Config.deleteConfigStatus
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__delete
     * @param options Request options.
     */
    deleteConfigStatus<T = DeleteConfigStatusResponseOK>(options: DeleteConfigStatusRequest): Promise<DeleteConfigStatusResponseOK | T>;
    /**
     * Load one object
     * Alternative usage: Object.getObject
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__get
     * @param options Request options.
     */
    getObject<T = GetObjectResponseOK>(options: GetObjectRequest): Promise<GetObjectResponseOK | T>;
    /**
     * Update an existing object in Assets
     * Alternative usage: Object.updateObject
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__put
     * @param options Request options.
     */
    updateObject<T = UpdateObjectResponseOK>(options: UpdateObjectRequest): Promise<UpdateObjectResponseOK | T>;
    /**
     * Delete the referenced object
     * Alternative usage: Object.deleteObject
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__delete
     * @param options Request options.
     */
    deleteObject<T = DeleteObjectResponseOK>(options: DeleteObjectRequest): Promise<DeleteObjectResponseOK | T>;
    /**
     * Create a new object in Assets
     * Alternative usage: Object.createObject
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object_create_post
     * @param options Request options.
     */
    createObject<T = CreateObjectResponseOK>(options: CreateObjectRequest): Promise<CreateObjectResponseOK | T>;
    /**
     * Retrieve a list of objects based on an AQL.
     * Alternative usage: Object.getObjectsWithAql
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object_navlist_aql_post
     * @param options Request options.
     */
    getObjectsWithAql<T = GetObjectsWithAqlResponseOK>(options: GetObjectsWithAqlRequest): Promise<GetObjectsWithAqlResponseOK | T>;
    /**
     * List all attributes for the given object
     * Alternative usage: Object.Attribute.getAttributes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__attributes_get
     * @param options Request options.
     */
    getObjectAttributes<T = GetObjectAttributesResponseOK>(options: GetObjectAttributesRequest): Promise<GetObjectAttributesResponseOK | T>;
    /**
     * Creates a new attribute for a given attribute.
     * Alternative usage: Object.Attribute.createAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute_create_post
     * @param options Request options.
     */
    createObjectAttribute<T = CreateObjectAttributeResponseOK>(options: CreateObjectAttributeRequest): Promise<CreateObjectAttributeResponseOK | T>;
    /**
     * Update an already existing object attribute
     * Alternative usage: Object.Attribute.updateAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute__id__put
     * @param options Request options.
     */
    updateObjectAttribute<T = UpdateObjectAttributeResponseOK>(options: UpdateObjectAttributeRequest): Promise<UpdateObjectAttributeResponseOK | T>;
    /**
     * Load a single object attribute
     * Alternative usage: Object.Attribute.getAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute__id__get
     * @param options Request options.
     */
    getObjectAttribute<T = GetObjectAttributeResponseOK>(options: GetObjectAttributeRequest): Promise<GetObjectAttributeResponseOK | T>;
    /**
     * Retrieve the history entries for this object
     * Alternative usage: Object.History.getHistory
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__history_get
     * @param options Request options.
     */
    getObjectHistory<T = GetObjectHistoryResponseOK>(options: GetObjectHistoryRequest): Promise<GetObjectHistoryResponseOK | T>;
    /**
     * Find all references for an object
     * Alternative usage: Object.Reference.getReferences
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__referenceinfo_get
     * @param options Request options.
     */
    getObjectReferences<T = GetObjectReferencesResponseOK>(options: GetObjectReferencesRequest): Promise<GetObjectReferencesResponseOK | T>;
    /**
     * Relation between Jira issues and Assets objects
     * Alternative usage: Object.Ticket.getConnectedTickets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectconnectedtickets__objectid__get
     * @param options Request options.
     */
    getObjectConnectedTickets<T = GetObjectConnectedTicketsResponseOK>(options: GetObjectConnectedTicketsRequest): Promise<GetObjectConnectedTicketsResponseOK | T>;
    /**
     * Resource to find object schemas in Assets
     * Alternative usage: Object.Schema.getSchemas
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema_list_get
     * @param options Request options.
     */
    getObjectSchemas<T = GetObjectSchemasResponseOK>(options?: GetObjectSchemasRequest): Promise<GetObjectSchemasResponseOK | T>;
    /**
     * Create schema
     * Alternative usage: Object.Schema.createSchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema_create_post
     * @param options Request options.
     */
    createObjectSchema<T = CreateObjectSchemaResponseOK>(options: CreateObjectSchemaRequest): Promise<CreateObjectSchemaResponseOK | T>;
    /**
     * Update schema
     * Alternative usage: Object.Schema.updateSchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__put
     * @param options Request options.
     */
    updateObjectSchema<T = UpdateObjectSchemaResponseOK>(options: UpdateObjectSchemaRequest): Promise<UpdateObjectSchemaResponseOK | T>;
    /**
     * Get schema
     * Alternative usage: Object.Schema.getSchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__get
     * @param options Request options.
     */
    getObjectSchema<T = GetObjectSchemaResponseOK>(options: GetObjectSchemaRequest): Promise<GetObjectSchemaResponseOK | T>;
    /**
     * Delete schema
     * Alternative usage: Object.Schema.deleteSchema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__delete
     * @param options Request options.
     */
    deleteObjectSchema<T = DeleteObjectSchemaResponseOK>(options: DeleteObjectSchemaRequest): Promise<DeleteObjectSchemaResponseOK | T>;
    /**
     * Find all object type attributes for this object schema
     * Alternative usage: Object.Schema.getSchemaObjectTypeAttributes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__attributes_get
     * @param options Request options.
     */
    getObjectSchemaObjectTypeAttributes<T = GetObjectSchemaObjectTypeAttributesResponseOK>(options: GetObjectSchemaObjectTypeAttributesRequest): Promise<GetObjectSchemaObjectTypeAttributesResponseOK | T>;
    /**
     * Find all object types for this object schema
     * Alternative usage: Object.Schema.getSchemaObjectTypes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__objecttypes_flat_get
     * @param options Request options.
     */
    getObjectSchemaObjectTypes<T = GetObjectSchemaObjectTypesResponseOK>(options: GetObjectSchemaObjectTypesRequest): Promise<GetObjectSchemaObjectTypesResponseOK | T>;
    /**
     * Resource to get object type
     * Alternative usage: Object.Type.getType
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__get
     * @param options Request options.
     */
    getObjectType<T = GetObjectTypeResponseOK>(options: GetObjectTypeRequest): Promise<GetObjectTypeResponseOK | T>;
    /**
     * Update the object type
     * Alternative usage: Object.Type.updateType
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__put
     * @param options Request options.
     */
    updateObjectType<T = UpdateObjectTypeResponseOK>(options: UpdateObjectTypeRequest): Promise<UpdateObjectTypeResponseOK | T>;
    /**
     * Delete the object type
     * Alternative usage: Object.Type.deleteType
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__delete
     * @param options Request options.
     */
    deleteObjectType<T = DeleteObjectTypeResponseOK>(options: DeleteObjectTypeRequest): Promise<DeleteObjectTypeResponseOK | T>;
    /**
     * Find all object type attribute for this object type
     * Alternative usage: Object.Type.getTypeAttributes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__attributes_get
     * @param options Request options.
     */
    getObjectTypeAttributes<T = GetObjectTypeAttributesResponseOK>(options: GetObjectTypeAttributesRequest): Promise<GetObjectTypeAttributesResponseOK | T>;
    /**
     * Change position of this object type
     * Alternative usage: Object.Type.changeTypePosition
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__position_post
     * @param options Request options.
     */
    changeObjectTypePosition<T = ChangeObjectTypePositionResponseOK>(options: ChangeObjectTypePositionRequest): Promise<ChangeObjectTypePositionResponseOK | T>;
    /**
     * Create object type
     * Alternative usage: Object.Type.createType
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype_create_post
     * @param options Request options.
     */
    createObjectType<T = CreateObjectTypeResponseOK>(options: CreateObjectTypeRequest): Promise<CreateObjectTypeResponseOK | T>;
    /**
     * Create object type attribute
     * Alternative usage: Object.Type.Attribute.createAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__objecttypeid__post
     * @param options Request options.
     */
    createObjectTypeAttribute<T = CreateObjectTypeAttributeResponseOK>(options: CreateObjectTypeAttributeRequest): Promise<CreateObjectTypeAttributeResponseOK | T>;
    /**
     * Update object type attribute
     * Alternative usage: Object.Type.Attribute.updateAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__objecttypeid___id__put
     * @param options Request options.
     */
    updateObjectTypeAttribute<T = UpdateObjectTypeAttributeResponseOK>(options: UpdateObjectTypeAttributeRequest): Promise<UpdateObjectTypeAttributeResponseOK | T>;
    /**
     * Delete object type attribute
     * Alternative usage: Object.Type.Attribute.deleteAttribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__id__delete
     * @param options Request options.
     */
    deleteObjectTypeAttribute<T = DeleteObjectTypeAttributeResponseOK>(options: DeleteObjectTypeAttributeRequest): Promise<DeleteObjectTypeAttributeResponseOK | T>;
}
declare class AttachmentGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get object attachments
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments_object__objectid__get
     * @param options Request options.
     */
    getAttachments<T = GetAttachmentsResponseOK>(options: GetAttachmentsRequest): Promise<GetAttachmentsResponseOK | T>;
    /**
     * Create object attachments
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments_object__objectid__post
     * @param options Request options.
     */
    createAttachments<T = CreateAttachmentsResponseOK>(options: CreateAttachmentsRequest): Promise<CreateAttachmentsResponseOK | T>;
    /**
     * Delete object attachment
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#attachments__attachmentid__delete
     * @param options Request options.
     */
    deleteAttachment<T = DeleteAttachmentResponseOK>(options: DeleteAttachmentRequest): Promise<DeleteAttachmentResponseOK | T>;
}
declare class CommentGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Create comments on objects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#comment_create_post
     * @param options Request options.
     */
    createComment<T = CreateCommentResponseOK>(options: CreateCommentRequest): Promise<CreateCommentResponseOK | T>;
    /**
     * Get comments on objects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#comment_object__objectid__get
     * @param options Request options.
     */
    getComments<T = GetCommentsResponseOK>(options: GetCommentsRequest): Promise<GetCommentsResponseOK | T>;
}
declare class IconGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Load a single icon by id
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon__id__get
     * @param options Request options.
     */
    getIcon<T = GetIconResponseOK>(options: GetIconRequest): Promise<GetIconResponseOK | T>;
    /**
     * Get all existing global icons
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon_global_get
     * @param options Request options.
     */
    getGlobalIcons<T = GetGlobalIconsResponseOK>(options?: GetGlobalIconsRequest): Promise<GetGlobalIconsResponseOK | T>;
    /**
     * Fetch all configured icons from the object schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#icon_objectschema__objectschemaid__get
     * @param options Request options.
     */
    getIconsBySchema<T = GetIconsBySchemaResponseOK>(options: GetIconsBySchemaRequest): Promise<GetIconsBySchemaResponseOK | T>;
}
declare class ImportGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Start import
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#import_start__id__post
     * @param options Request options.
     */
    startImport<T = StartImportResponseOK>(options: StartImportRequest): Promise<StartImportResponseOK | T>;
}
declare class IndexGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Handle the indexing of Assets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#index_reindex_start_post
     * @param options Request options.
     */
    startReindex<T = StartReindexResponseOK>(options?: StartReindexRequest): Promise<StartReindexResponseOK | T>;
    /**
     * Only applicable in a Data Center environment. Resource to start a re-index of the current node. This reindex will not clean the entire cluster just refresh the objects in cache on the current data center node
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#index_reindex_currentnode_post
     * @param options Request options.
     */
    startCurrentModeReindex<T = StartCurrentModeReindexResponseOK>(options?: StartCurrentModeReindexRequest): Promise<StartCurrentModeReindexResponseOK | T>;
}
declare class AqlGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get objects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#aql_objects_get
     * @param options Request options.
     */
    getObjects<T = GetObjectsResponseOK>(options?: GetObjectsRequest): Promise<GetObjectsResponseOK | T>;
}
declare class ProgressGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Show ongoing Assets processes
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#progress_category_assets_reindex_reindex_get
     * @param options Request options.
     */
    getReindexProgress<T = GetReindexProgressResponseOK>(options?: GetReindexProgressRequest): Promise<GetReindexProgressResponseOK | T>;
    /**
     * Get progress for import source
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#progress_category_imports__id__get
     * @param options Request options.
     */
    getImportProgress<T = GetImportProgressResponseOK>(options: GetImportProgressRequest): Promise<GetImportProgressResponseOK | T>;
}
declare class QRCodeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get QR code for object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#qrcode_object__objectid__code_png_get
     * @param options Request options.
     */
    getQrCode<T = GetQrCodeResponseOK>(options: GetQrCodeRequest): Promise<GetQrCodeResponseOK | T>;
}
declare class ConfigGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get the Assets statuses
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype_get
     * @param options Request options.
     */
    getConfigStatuses<T = GetConfigStatusesResponseOK>(options: GetConfigStatusesRequest): Promise<GetConfigStatusesResponseOK | T>;
    /**
     * Create status
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype_post
     * @param options Request options.
     */
    createConfigStatus<T = CreateConfigStatusResponseOK>(options: CreateConfigStatusRequest): Promise<CreateConfigStatusResponseOK | T>;
    /**
     * Get status
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__get
     * @param options Request options.
     */
    getConfigStatus<T = GetConfigStatusResponseOK>(options: GetConfigStatusRequest): Promise<GetConfigStatusResponseOK | T>;
    /**
     * Update status
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__put
     * @param options Request options.
     */
    updateConfigStatus<T = UpdateConfigStatusResponseOK>(options: UpdateConfigStatusRequest): Promise<UpdateConfigStatusResponseOK | T>;
    /**
     * Delete status
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#config_statustype__id__delete
     * @param options Request options.
     */
    deleteConfigStatus<T = DeleteConfigStatusResponseOK>(options: DeleteConfigStatusRequest): Promise<DeleteConfigStatusResponseOK | T>;
}
declare class ObjectGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Attribute: ObjectAttributeGroup;
    History: ObjectHistoryGroup;
    Reference: ObjectReferenceGroup;
    Ticket: ObjectTicketGroup;
    Schema: ObjectSchemaGroup;
    Type: ObjectTypeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Load one object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__get
     * @param options Request options.
     */
    getObject<T = GetObjectResponseOK>(options: GetObjectRequest): Promise<GetObjectResponseOK | T>;
    /**
     * Update an existing object in Assets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__put
     * @param options Request options.
     */
    updateObject<T = UpdateObjectResponseOK>(options: UpdateObjectRequest): Promise<UpdateObjectResponseOK | T>;
    /**
     * Delete the referenced object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__delete
     * @param options Request options.
     */
    deleteObject<T = DeleteObjectResponseOK>(options: DeleteObjectRequest): Promise<DeleteObjectResponseOK | T>;
    /**
     * Create a new object in Assets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object_create_post
     * @param options Request options.
     */
    createObject<T = CreateObjectResponseOK>(options: CreateObjectRequest): Promise<CreateObjectResponseOK | T>;
    /**
     * Retrieve a list of objects based on an AQL.
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object_navlist_aql_post
     * @param options Request options.
     */
    getObjectsWithAql<T = GetObjectsWithAqlResponseOK>(options: GetObjectsWithAqlRequest): Promise<GetObjectsWithAqlResponseOK | T>;
}
declare class ObjectAttributeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * List all attributes for the given object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__attributes_get
     * @param options Request options.
     */
    getAttributes<T = GetObjectAttributesResponseOK>(options: GetObjectAttributesRequest): Promise<GetObjectAttributesResponseOK | T>;
    /**
     * Creates a new attribute for a given attribute.
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute_create_post
     * @param options Request options.
     */
    createAttribute<T = CreateObjectAttributeResponseOK>(options: CreateObjectAttributeRequest): Promise<CreateObjectAttributeResponseOK | T>;
    /**
     * Update an already existing object attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute__id__put
     * @param options Request options.
     */
    updateAttribute<T = UpdateObjectAttributeResponseOK>(options: UpdateObjectAttributeRequest): Promise<UpdateObjectAttributeResponseOK | T>;
    /**
     * Load a single object attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectattribute__id__get
     * @param options Request options.
     */
    getAttribute<T = GetObjectAttributeResponseOK>(options: GetObjectAttributeRequest): Promise<GetObjectAttributeResponseOK | T>;
}
declare class ObjectHistoryGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Retrieve the history entries for this object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__history_get
     * @param options Request options.
     */
    getHistory<T = GetObjectHistoryResponseOK>(options: GetObjectHistoryRequest): Promise<GetObjectHistoryResponseOK | T>;
}
declare class ObjectReferenceGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Find all references for an object
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#object__id__referenceinfo_get
     * @param options Request options.
     */
    getReferences<T = GetObjectReferencesResponseOK>(options: GetObjectReferencesRequest): Promise<GetObjectReferencesResponseOK | T>;
}
declare class ObjectTicketGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Relation between Jira issues and Assets objects
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectconnectedtickets__objectid__get
     * @param options Request options.
     */
    getConnectedTickets<T = GetObjectConnectedTicketsResponseOK>(options: GetObjectConnectedTicketsRequest): Promise<GetObjectConnectedTicketsResponseOK | T>;
}
declare class ObjectSchemaGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Resource to find object schemas in Assets
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema_list_get
     * @param options Request options.
     */
    getSchemas<T = GetObjectSchemasResponseOK>(options?: GetObjectSchemasRequest): Promise<GetObjectSchemasResponseOK | T>;
    /**
     * Create schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema_create_post
     * @param options Request options.
     */
    createSchema<T = CreateObjectSchemaResponseOK>(options: CreateObjectSchemaRequest): Promise<CreateObjectSchemaResponseOK | T>;
    /**
     * Update schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__put
     * @param options Request options.
     */
    updateSchema<T = UpdateObjectSchemaResponseOK>(options: UpdateObjectSchemaRequest): Promise<UpdateObjectSchemaResponseOK | T>;
    /**
     * Get schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__get
     * @param options Request options.
     */
    getSchema<T = GetObjectSchemaResponseOK>(options: GetObjectSchemaRequest): Promise<GetObjectSchemaResponseOK | T>;
    /**
     * Delete schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__delete
     * @param options Request options.
     */
    deleteSchema<T = DeleteObjectSchemaResponseOK>(options: DeleteObjectSchemaRequest): Promise<DeleteObjectSchemaResponseOK | T>;
    /**
     * Find all object type attributes for this object schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__attributes_get
     * @param options Request options.
     */
    getSchemaObjectTypeAttributes<T = GetObjectSchemaObjectTypeAttributesResponseOK>(options: GetObjectSchemaObjectTypeAttributesRequest): Promise<GetObjectSchemaObjectTypeAttributesResponseOK | T>;
    /**
     * Find all object types for this object schema
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objectschema__id__objecttypes_flat_get
     * @param options Request options.
     */
    getSchemaObjectTypes<T = GetObjectSchemaObjectTypesResponseOK>(options: GetObjectSchemaObjectTypesRequest): Promise<GetObjectSchemaObjectTypesResponseOK | T>;
}
declare class ObjectTypeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Attribute: ObjectTypeAttributeGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Resource to get object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__get
     * @param options Request options.
     */
    getType<T = GetObjectTypeResponseOK>(options: GetObjectTypeRequest): Promise<GetObjectTypeResponseOK | T>;
    /**
     * Update the object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__put
     * @param options Request options.
     */
    updateType<T = UpdateObjectTypeResponseOK>(options: UpdateObjectTypeRequest): Promise<UpdateObjectTypeResponseOK | T>;
    /**
     * Delete the object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__delete
     * @param options Request options.
     */
    deleteType<T = DeleteObjectTypeResponseOK>(options: DeleteObjectTypeRequest): Promise<DeleteObjectTypeResponseOK | T>;
    /**
     * Find all object type attribute for this object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__attributes_get
     * @param options Request options.
     */
    getTypeAttributes<T = GetObjectTypeAttributesResponseOK>(options: GetObjectTypeAttributesRequest): Promise<GetObjectTypeAttributesResponseOK | T>;
    /**
     * Change position of this object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype__id__position_post
     * @param options Request options.
     */
    changeTypePosition<T = ChangeObjectTypePositionResponseOK>(options: ChangeObjectTypePositionRequest): Promise<ChangeObjectTypePositionResponseOK | T>;
    /**
     * Create object type
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttype_create_post
     * @param options Request options.
     */
    createType<T = CreateObjectTypeResponseOK>(options: CreateObjectTypeRequest): Promise<CreateObjectTypeResponseOK | T>;
}
declare class ObjectTypeAttributeGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Create object type attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__objecttypeid__post
     * @param options Request options.
     */
    createAttribute<T = CreateObjectTypeAttributeResponseOK>(options: CreateObjectTypeAttributeRequest): Promise<CreateObjectTypeAttributeResponseOK | T>;
    /**
     * Update object type attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__objecttypeid___id__put
     * @param options Request options.
     */
    updateAttribute<T = UpdateObjectTypeAttributeResponseOK>(options: UpdateObjectTypeAttributeRequest): Promise<UpdateObjectTypeAttributeResponseOK | T>;
    /**
     * Delete object type attribute
     * Documentation: https://insight-javadoc.riada.io/assets-rest/#objecttypeattribute__id__delete
     * @param options Request options.
     */
    deleteAttribute<T = DeleteObjectTypeAttributeResponseOK>(options: DeleteObjectTypeAttributeRequest): Promise<DeleteObjectTypeAttributeResponseOK | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map