/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { HeadersOption } from '@managed-api/commons-core';
import { ObjectsResponse } from '../definitions/Object';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface GetObjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The query to determine which objects that should be fetched. For example, objectType = "Computer". An empty query means all objects are fetched.
     */
    qlQuery?: string;
    /**
     * Which page to fetch when paginating through the response
     */
    page?: number;
    /**
     * The amount of objects returned per page
     */
    resultPerPage?: number;
    /**
     * Should the objects attributes be included in the response. If this parameter is false only the information on the object will be returned and the object attributes will not be present
     */
    includeAttributes?: boolean;
    /**
     * How many levels of attributes should be included. For example, consider object A, which has a reference to object B, which has a reference to object C. If object A is included in the response and includeAttributesDeep=1, object A's reference to object B will be included in the attributes of object A, but object B's reference to object C will not be included. However, if includeAttributesDeep=2 then object B's reference to object C will be included in object B's attributes.
     */
    includeAttributesDeep?: number;
    /**
     * Should the response include the object type attribute definition for each attribute that is returned with the objects
     */
    includeTypeAttributes?: boolean;
    /**
     * Include information about open issues and attachments. Objects should have extra information if open tickets are connected to the object, or if the object has attachments.
     */
    includeExtendedInfo?: boolean;
}
export interface GetObjectsResponseOK extends ObjectsResponse {
}
export interface GetObjectsResponseError extends CommonError {
}
//# sourceMappingURL=aql.d.ts.map