/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { HeadersOption } from '@managed-api/commons-core';
import { ObjectTypeAttribute } from '../../../definitions/Object';
import { CommonError, ErrorStrategyOption } from '../../../errorStrategy';
export interface CreateObjectTypeAttributeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The object type id that has this object type attribute associated with it
     */
    objectTypeId: number;
    body: {
        name: string;
        label?: boolean;
        description?: string;
        /**
         * 0 - Default
         * 1 - Object reference
         * 2 - User
         * 3 - Confluence
         * 4 - Group
         * 5 - Version
         * 6 - Project
         * 7 - Status
         */
        type: number;
        /**
         * -1 - None
         * 0 - Text
         * 1 - Integer
         * 2 - Boolean
         * 3 - Double
         * 4 - Date
         * 5 - Time
         * 6 - DateTime
         * 7 - Url
         * 8 - Email
         * 9 - Textarea
         * 10 - Select
         * 11 - IP Address
         */
        defaultTypeId?: number;
        /**
         * It is mandatory for Type = Object reference and should point to the referenced object type id
         */
        typeValue?: string;
        /**
         * Valid for Type User.The Jira groups to restrict selection to
         */
        typeValueMulti?: string[];
        /**
         * Valid for Type Url, User, Object and Confluence.For Url(DISABLED, ENABLED), for Object(ReferenceTypeId), for User(SHOW_PROFILE, HIDE_PROFILE), for Confluence(Confluence Space Id).It is mandatory for Type = Object reference
         */
        additionalValue?: string;
        /**
         * Valid for Type Email, Select, Object, User, Group, Version and Project
         */
        minimumCardinality?: number;
        /**
         * Valid for Type Email, Select, Object, User, Group, Version and Project
         */
        maximumCardinality?: number;
        /**
         * Valid for Integer and Double object type attributes
         */
        suffix?: string;
        /**
         * Valid for Type = Object reference and describes if children object types should be included in the selectable objects as well
         */
        includeChildObjectTypes?: boolean;
        /**
         * Hide the object type attributes for Assets Users
         */
        hidden?: boolean;
        /**
         * Should the values be unique for object attributes associated with this object type attribute
         */
        uniqueAttribute?: boolean;
        /**
         * Valid for Type Integer and Double.Should a sum be included in the view
         */
        summable?: boolean;
        /**
         * Valid for Type Text and Email
         */
        regexValidation?: string;
        /**
         * Valid for Type object reference
         */
        qlQuery?: string;
        /**
         * Valid for Type Select.A comma separated list of all selectable options
         */
        options?: string;
    };
}
export interface CreateObjectTypeAttributeResponseOK extends ObjectTypeAttribute {
}
export interface CreateObjectTypeAttributeResponseError extends CommonError {
}
export interface UpdateObjectTypeAttributeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The object type id that has this object type attribute associated with it
     */
    objectTypeId: number;
    /**
     * The object type attribute to manipulate
     */
    id: number;
    body: {
        name: string;
        label?: boolean;
        description?: string;
        /**
         * 0 - Default
         * 1 - Object reference
         * 2 - User
         * 3 - Confluence
         * 4 - Group
         * 5 - Version
         * 6 - Project
         * 7 - Status
         */
        type: number;
        /**
         * -1 - None
         * 0 - Text
         * 1 - Integer
         * 2 - Boolean
         * 3 - Double
         * 4 - Date
         * 5 - Time
         * 6 - DateTime
         * 7 - Url
         * 8 - Email
         * 9 - Textarea
         * 10 - Select
         * 11 - IP Address
         */
        defaultTypeId?: number;
        /**
         * It is mandatory for Type = Object reference and should point to the referenced object type id
         */
        typeValue?: string;
        /**
         * Valid for Type User.The Jira groups to restrict selection to
         */
        typeValueMulti?: string[];
        /**
         * Valid for Type Url, User, Object and Confluence.For Url(DISABLED, ENABLED), for Object(ReferenceTypeId), for User(SHOW_PROFILE, HIDE_PROFILE), for Confluence(Confluence Space Id).It is mandatory for Type = Object reference
         */
        additionalValue?: string;
        /**
         * Valid for Type Email, Select, Object, User, Group, Version and Project
         */
        minimumCardinality?: number;
        /**
         * Valid for Type Email, Select, Object, User, Group, Version and Project
         */
        maximumCardinality?: number;
        /**
         * Valid for Integer and Double object type attributes
         */
        suffix?: string;
        /**
         * Valid for Type = Object reference and describes if children object types should be included in the selectable objects as well
         */
        includeChildObjectTypes?: boolean;
        /**
         * Hide the object type attributes for Assets Users
         */
        hidden?: boolean;
        /**
         * Should the values be unique for object attributes associated with this object type attribute
         */
        uniqueAttribute?: boolean;
        /**
         * Valid for Type Integer and Double.Should a sum be included in the view
         */
        summable?: boolean;
        /**
         * Valid for Type Text and Email
         */
        regexValidation?: string;
        /**
         * Valid for Type object reference
         */
        qlQuery?: string;
        /**
         * Valid for Type Select.A comma separated list of all selectable options
         */
        options?: string;
    };
}
export interface UpdateObjectTypeAttributeResponseOK extends ObjectTypeAttribute {
}
export interface UpdateObjectTypeAttributeResponseError extends CommonError {
}
export interface DeleteObjectTypeAttributeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The object type attribute to manipulate
     */
    id: number;
}
export type DeleteObjectTypeAttributeResponseOK = undefined;
export interface DeleteObjectTypeAttributeResponseError extends CommonError {
}
//# sourceMappingURL=attribute.d.ts.map